@@ -13,7 +13,7 @@ use Carp;
 use strict;
 use warnings;
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 my $Time_HiRes_avail;
 my $color_avail;
@@ -160,7 +160,7 @@ sub import {
 our $ZZ = 0;
 
 sub DB__DB {
-    return if $_GLOBAL_DESTRUCTION ; # && !$DB::single;
+    return if $_GLOBAL_DESTRUCTION;
     return unless $Devel::DumpTrace::TRACE;
 
     my ($p, $f, $l) = caller();
@@ -1020,16 +1020,14 @@ sub __END {
     handle_ALL_deferred_output();
 }
 
-END {
-    &__END;
-}
-
 # RT#76864
 {
     # Devel::DumpTrace is typically loaded before any other module
     # (from the -d:DumpTrace switch). Running this  threads-specific
     # code in a  CHECK  block gives the traced program a chance to
     # load  threads  later.
+    # We'll also use it to declare a late END block that is more
+    # likely to get executed first at global destruction.
     no warnings 'void';
     CHECK {
         if ($INC{'threads.pm'}) {
@@ -1051,8 +1049,11 @@ END {
             }
         }
     }
+    INIT { eval 'END { &__END }' }
 }
 
+END { &__END; }
+
 
 ##################################################################
 # Devel::DumpTrace::VerboseLevel: tie class for $Devel::DumpTrace::TRACE.
@@ -1113,7 +1114,7 @@ Devel::DumpTrace - Evaluate and print out each line before it is executed.
 
 =head1 VERSION
 
-0.23
+0.24
 
 =head1 SYNOPSIS
 
